@@ -252,4 +252,9 @@ TUBE_IGNORE_KEYS = (
     "alt_title",
     "format_index",
     "requested_subtitles",
+    "entries",
+    "dislike_count",
+    "manifest_url",
+    "manifest_stream_number",
+    "start_time",
 )
