@@ -10,7 +10,7 @@ from xklb.subtitle import externalize_subtitle
 from xklb.utils import cmd, log
 
 
-def construct_search_bindings(args, bindings, cf, columns) -> None:
+def construct_search_bindings(args, cf, bindings, columns) -> None:
     includes, excludes = db.gen_include_excludes(columns)
 
     for idx, inc in enumerate(args.include):
@@ -33,17 +33,34 @@ def construct_query(args) -> Tuple[str, dict]:
 
     cf.extend([" and " + w for w in args.where])
 
+    if args.created_within:
+        cf.append(
+            f"and time_created > cast(STRFTIME('%s', datetime( 'now', '-{args.created_within}', '-3 hours' )) as int)"
+        )
+    if args.created_before:
+        cf.append(
+            f"and time_created < cast(STRFTIME('%s', datetime( 'now', '-{args.created_before}', '-3 hours' )) as int)"
+        )
+    if args.changed_within:
+        cf.append(
+            f"and time_modified > cast(STRFTIME('%s', datetime( 'now', '-{args.changed_within}', '-3 hours' )) as int)"
+        )
+    if args.changed_before:
+        cf.append(
+            f"and time_modified < cast(STRFTIME('%s', datetime( 'now', '-{args.changed_before}', '-3 hours' )) as int)"
+        )
+
     args.table = "media"
     if args.db["media"].detect_fts():
         if args.include:
             args.table = db.fts_search(args, bindings)
             m_columns = {**m_columns, "rank": int}
         elif args.exclude:
-            construct_search_bindings(args, bindings, cf, m_columns)
+            construct_search_bindings(args, cf, bindings, m_columns)
     else:
-        construct_search_bindings(args, bindings, cf, m_columns)
+        construct_search_bindings(args, cf, bindings, m_columns)
 
-    if args.table == "media" and not any([args.partial, args.print, args.include, args.where]):
+    if args.table == "media" and not any([args.partial, args.print, cf, args.where]):
         limit = 60_000
         if args.random:
             limit = consts.DEFAULT_PLAY_QUEUE * 16
@@ -118,6 +135,14 @@ def usage(action, default_db) -> str:
         library {action} -ct "Office pair"  # equivalent
         If you don't know the exact name of your chromecast group run `catt scan`
 
+    Play media in order (similarly named episodes):
+        library {action} --play-in-order
+        There are multiple strictness levels of --play-in-order.
+        If things aren't playing in order try adding more `O`s:
+        library {action} -O    # fast
+        library {action} -OO   # slow, more complex algorithm
+        library {action} -OOO  # slow, ignores most filters
+
     Play recent partially-watched videos (requires mpv history):
         library {action} --partial       # play newest first
         library {action} --partial old   # play oldest first
@@ -244,6 +269,14 @@ def usage(action, default_db) -> str:
         library {action} -z-6  # less than 6 MB
         library {action} -z+6  # more than 6 MB
 
+    Constrain media by time_created:
+        library {action} --created-within '3 days'
+        library {action} --created-before '3 years'
+
+    Constrain media by time_modified:
+        library {action} --changed-within '3 days'
+        library {action} --changed-before '3 years'
+
     Constrain media by throughput:
         Bitrate information is not explicitly saved.
         You can use file size and duration as a proxy for throughput:
@@ -259,14 +292,6 @@ def usage(action, default_db) -> str:
         You can use multiple SQL ORDER BY expressions
         library {action} -u 'subtitle_count > 0 desc' # play media that has at least one subtitle first
 
-    Play media in order (similarly named episodes):
-        library {action} --play-in-order
-        There are multiple strictness levels of --play-in-order.
-        If things aren't playing in order try adding more `O`s:
-        library {action} -O    # fast
-        library {action} -OO   # slow, more complex algorithm
-        library {action} -OOO  # slow, ignores most filters
-
     Post-actions -- choose what to do after playing:
         library {action} --post-action delete  # delete file after playing
         library {action} -k ask  # ask after each whether to keep or delete
@@ -345,6 +370,11 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     parser.add_argument("--include", "-s", "--search", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
     parser.add_argument("--exclude", "-E", "-e", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
 
+    parser.add_argument("--created-within", help=argparse.SUPPRESS)
+    parser.add_argument("--created-before", help=argparse.SUPPRESS)
+    parser.add_argument("--changed-within", "--modified-within", help=argparse.SUPPRESS)
+    parser.add_argument("--changed-before", "--modified-before", help=argparse.SUPPRESS)
+
     parser.add_argument("--chromecast-device", "--cast-to", "-t", default=default_chromecast, help=argparse.SUPPRESS)
     parser.add_argument("--chromecast", "--cast", "-c", action="store_true", help=argparse.SUPPRESS)
     parser.add_argument("--with-local", "-wl", action="store_true", help=argparse.SUPPRESS)
